/*
 * Code for class CODE_PAGE_CONSTANTS
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "co41.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {CODE_PAGE_CONSTANTS}.utf7 */

EIF_REFERENCE F46_752 (EIF_REFERENCE Current)
{
	GTCX
	RTOSC (752,RTMS_EX_H("UTF-7",5,1414538039));
}

/* {CODE_PAGE_CONSTANTS}.utf8 */

EIF_REFERENCE F46_753 (EIF_REFERENCE Current)
{
	GTCX
	RTOSC (753,RTMS_EX_H("UTF-8",5,1414538040));
}

/* {CODE_PAGE_CONSTANTS}.utf16 */

EIF_REFERENCE F46_754 (EIF_REFERENCE Current)
{
	GTCX
	RTOSC (754,RTMS_EX_H("UTF-16",6,1345128758));
}

/* {CODE_PAGE_CONSTANTS}.utf32 */

EIF_REFERENCE F46_755 (EIF_REFERENCE Current)
{
	GTCX
	RTOSC (755,RTMS_EX_H("UTF-32",6,1345129266));
}

/* {CODE_PAGE_CONSTANTS}.utf16_le */

EIF_REFERENCE F46_756 (EIF_REFERENCE Current)
{
	GTCX
	RTOSC (756,RTMS_EX_H("UTF-16LE",8,312185413));
}

/* {CODE_PAGE_CONSTANTS}.utf32_le */

EIF_REFERENCE F46_757 (EIF_REFERENCE Current)
{
	GTCX
	RTOSC (757,RTMS_EX_H("UTF-32LE",8,345477701));
}

/* {CODE_PAGE_CONSTANTS}.utf16_be */

EIF_REFERENCE F46_758 (EIF_REFERENCE Current)
{
	GTCX
	RTOSC (758,RTMS_EX_H("UTF-16BE",8,312182853));
}

/* {CODE_PAGE_CONSTANTS}.utf32_be */

EIF_REFERENCE F46_759 (EIF_REFERENCE Current)
{
	GTCX
	RTOSC (759,RTMS_EX_H("UTF-32BE",8,345475141));
}

void EIF_Minit41 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
